@@ -21,7 +21,7 @@ try:
 except:
     def free_memory():
         gc.collect()
-sys.path.append("../src")
+# sys.path.append("../src")
 from .strategies import AvgUserStrategy
 import pandas as pd
 
@@ -46,14 +46,16 @@ class Column(BaseModel):
 
 class Schema(BaseModel):
     encoders: List[Column]
-    metric: Optional[str]='ip'
-    filters: Optional[List[Column]]=[]
-    user_encoders: Optional[List[Column]]=[]
-    id_col: Optional[str]='id'
+    metric: Optional[str] = 'ip'
+    index_factory: Optional[str] = ''
+    filters: Optional[List[Column]] = []
+    user_encoders: Optional[List[Column]] = []
+    id_col: Optional[str] = 'id'
     
     def to_dict(self):
         return {
             "metric": self.metric,
+            "index_factory": self.index_factory,
             "filters": [vars(c) for c in self.filters],
             "encoders": [vars(c) for c in self.encoders],
         }
@@ -133,7 +135,7 @@ async def api_index(data: Union[List[Dict[str, str]], str]):
     return {"status": "OK", "affected_partitions": affected_partitions}
 
 
-@api.post("/query")
+@api.post("/item_query")
 async def api_query(query: KnnQuery):
     if not strategy.schema_initialized():
         return {"status": "error", "message": "Schema not initialized"}
